@@ -1188,7 +1188,7 @@ propfind_result (void *userdata, const char *href, const ne_prop_result_set *set
 	time_t	time;
 	gulong  size;
 	ne_uri  uri;
-	char *unesc_path;
+	char *unesc_path, *unesc_ctx_path;
 
 	ctx = (PropfindContext *) userdata;
 
@@ -1205,10 +1205,10 @@ propfind_result (void *userdata, const char *href, const ne_prop_result_set *set
 	info = gnome_vfs_file_info_new ();
 	unesc_path = ne_path_unescape (uri.path);
 	info->name = g_path_get_basename (unesc_path);
-	NE_FREE (unesc_path);
 
+	unesc_ctx_path = ne_path_unescape (ctx->path);
 	DEBUG_HTTP_2 ("Comparing: \n\t[%s] \n\t[%s]", ctx->path, uri.path);
-	if (ne_path_compare (ctx->path, uri.path) == 0) {
+	if (ne_path_compare (unesc_ctx_path, unesc_path) == 0) {
 		DEBUG_HTTP_3 ("target");
 		ctx->target = info;
 
@@ -1225,6 +1225,8 @@ propfind_result (void *userdata, const char *href, const ne_prop_result_set *set
 		ctx->children = g_list_append (ctx->children, info);
 	}
 
+	NE_FREE (unesc_ctx_path);
+	NE_FREE (unesc_path);
 	ne_uri_free (&uri);
 
 	/* getlastmodified */
@@ -1617,6 +1619,8 @@ http_acquire_connection (HttpContext *context)
 		return GNOME_VFS_ERROR_INTERNAL;
 	}
 
+	ne_set_read_timeout (session, 30);
+
 	user_agent = getenv (CUSTOM_USER_AGENT_VARIABLE);
 	   
 	if (user_agent == NULL) {
@@ -2451,6 +2455,7 @@ do_create (GnomeVFSMethod	 *method,
 
 	hctx = handle->context;	
 
+put_start:
 	req = ne_request_create (hctx->session, "PUT", hctx->path);
 
 	/* Apache seems to not handle "If-None-Match: *" correctly 
@@ -2473,6 +2478,20 @@ do_create (GnomeVFSMethod	 *method,
 	ne_set_request_body_buffer (req, NULL, 0);
 	
 	res = ne_request_dispatch (req);
+
+	if (res == NE_REDIRECT) {
+		ne_request_destroy (req);
+		req = NULL;
+		
+		result = http_follow_redirect (hctx);
+		
+		if (result == GNOME_VFS_OK) {
+			goto put_start;
+		} else {
+			return result;
+		}
+	}
+
 	result 	= resolve_result (res, req);
 	ne_request_destroy (req);
 	
